==> ifnode-1.6.3.tgz: package/README.md <==
            ____  _________
           /   / /        /
          /   / /   _____/_    ___  _______    _____      ______
         /   / /   /__  /  |  /  / /  ___  \  /     \    /  ___/
        /   / /      / /   | /  / /  /  /  / /  / \  \  /  /_
       /   / /   ___/ /  /||/  / /  /  /  / /  /  /  / /  __/
      /   / /   /    /  / |   / /  /__/  / /  /__/  / /  /___
     /   / /   /    /__/  |__/  \_______/  \_______/ /______/
    /___/ /___/

    Best MVC Framework for node.js :^)

[![Build Status](https://travis-ci.org/ifnode/ifnode.svg?branch=master)](https://travis-ci.org/ifnode/ifnode) [![NSP Status](https://nodesecurity.io/orgs/ifnode/projects/b02ae270-a972-4132-a391-8299e270d084/badge)](https://nodesecurity.io/orgs/ifnode/projects/b02ae270-a972-4132-a391-8299e270d084)

### What is `ifnode`?

+ Simple, light and flexible MVC Framework for **[node.js](https://nodejs.org)** and **[io.js](https://iojs.org)**
+ Based in **[express.js](https://expressjs.com)** and other awesome node modules
+ Inspired by **[Yii](http://yiiframework.com)**, **[Ruby on Rails](http://rubyonrails.org)**, etc

### Installation

For install `ifnode` type command:

```bash
npm install -S ifnode
```

### Ideology

* `ifnode`'s main idea is not dictate for developer what need to do but make all for simplification work
* `ifnode` is simple, understandable and light
* `ifnode` build on `express.js`: get all possibilities of module (routes, middleware) and extends opportunities
* `ifnode` have the four build items:
  * **[extensions](https://ifnode.com/docs/app/extensions)**
  * **[models](https://ifnode.com/docs/app/models)**
  * **[components](https://ifnode.com/docs/app/components)**
  * **[controllers](https://ifnode.com/docs/app/controllers)**
* `ifnode` have a **[plugins system](https://ifnode.com/docs/app/plugins)**
* `ifnode` use **[Service Locator Pattern](https://en.wikipedia.org/wiki/Service_locator_pattern)**

### Documentation

You can explore the **[documentation](https://ifnode.com/docs/intro)**. Also you can check `ifnode` applications **[examples](https://github.com/ifnode/examples)**.

© **[ifnode](https://ifnode.com/)**

==> ifnode-1.7.1.tgz: package/README.md <==
            ____  _________
           /   / /        /
          /   / /   _____/_    ___  _______    _____      ______
         /   / /   /__  /  |  /  / /  ___  \  /     \    /  ___/
        /   / /      / /   | /  / /  /  /  / /  / \  \  /  /_
       /   / /   ___/ /  /||/  / /  /  /  / /  /  /  / /  __/
      /   / /   /    /  / |   / /  /__/  / /  /__/  / /  /___
     /   / /   /    /__/  |__/  \_______/  \_______/ /______/
    /___/ /___/

    Best MVC Framework for node.js :^)

[![Build Status](https://travis-ci.org/ifnode/ifnode.svg?branch=master)](https://travis-ci.org/ifnode/ifnode)
[![Coverage Status](https://coveralls.io/repos/github/ifnode/ifnode/badge.svg?branch=master)](https://coveralls.io/github/ifnode/ifnode?branch=master)
[![Known Vulnerabilities](https://snyk.io/test/github/ifnode/ifnode/badge.svg)](https://snyk.io/test/github/ifnode/ifnode) [![NSP Status](https://nodesecurity.io/orgs/ifnode/projects/b02ae270-a972-4132-a391-8299e270d084/badge)](https://nodesecurity.io/orgs/ifnode/projects/b02ae270-a972-4132-a391-8299e270d084)

### What is `ifnode`?

+ Simple, light and flexible MVC Framework for **[node.js](https://nodejs.org)** and **[io.js](https://iojs.org)**
+ Based in **[express.js](https://expressjs.com)** and other awesome node modules
+ Inspired by **[Yii](http://yiiframework.com)**, **[Ruby on Rails](http://rubyonrails.org)**, etc

### Installation

For install `ifnode` type command:

```bash
npm install -S ifnode
```

### Ideology

* `ifnode`'s main idea is not dictate for developer what need to do but make all for simplification work
* `ifnode` is simple, understandable and light
* `ifnode` build on `express.js`: get all possibilities of module (routes, middleware) and extends opportunities
* `ifnode` have the four build items:
  * **[extensions](https://ifnode.com/docs/app/extensions)**
  * **[models](https://ifnode.com/docs/app/models)**
  * **[components](https://ifnode.com/docs/app/components)**
  * **[controllers](https://ifnode.com/docs/app/controllers)**
* `ifnode` have a **[plugins system](https://ifnode.com/docs/app/plugins)**
* `ifnode` use **[Service Locator Pattern](https://en.wikipedia.org/wiki/Service_locator_pattern)**

### Documentation

You can explore the **[documentation](https://ifnode.com/docs/intro)**. Also you can check `ifnode` applications **[examples](https://github.com/ifnode/examples)**.

© **[ifnode](https://ifnode.com/)**
